<?php
/**
 *
 * Load the API components.
 *
 * @since 1.0.0
 *
 * @package SplendorStudio\Framework\API
*/

abstract class Fancify_Lite_Controller {

	private static $instances = array();
	protected $theme_slug = false;
	protected $model;

	/**
	 * Provides access to a single instance of a module using the singleton pattern
	 *
	 * @since    1.0.0
	 */
	public static function get_instance() {

		$classname = get_called_class();

		if ( ! isset( self::$instances[ $classname ] ) ) {
			self::$instances[ $classname ] = new $classname();
		}
		return self::$instances[ $classname ];

	}

	/**
	 * Get model
	 *
	 * @since    1.0.0
	 */
	protected static function get_model() {

		return static::get_instance()->model;

	}	

	/**
	 * Render a template
	 *
	 * @since    1.0.0
	 */
	protected static function render_template( $default_template_path = false, $variables = array(), $require = 'once' ){
		
		if ( ! $template_path = locate_template( basename( $default_template_path ) ) ) {
			$template_path =  FANCIFY_TEMPLATES_PATH . $default_template_path;
		}

		if ( is_file( $template_path ) ) {
			extract( $variables );
			ob_start();
			if ( 'always' == $require ) {
				require( $template_path );// phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound -- valid usecase
			} else {
				require_once( $template_path );// phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound -- valid usecase
			}
			$template_content = apply_filters( 'fancify_lite_template_content', ob_get_clean(), $default_template_path, $template_path, $variables );
		} else {
			$template_content = '';
		}

		return $template_content;
	}

	/**
	 * Constructor
	 *
	 */
	abstract protected function __construct();

	/**
	 * Register callbacks for actions and filters
	 * 
	 */
	abstract protected function register_hook_callbacks();

}
